@@ -4,6 +4,7 @@ pub mod cube;
 pub mod mesh;
 pub mod mesh_loader;
 pub mod smooth_triangle;
+pub mod track;
 pub mod triangle;
 
-pub use self::{cube::*, mesh::*, mesh_loader::*, smooth_triangle::*, triangle::*};
+pub use self::{cube::*, mesh::*, mesh_loader::*, smooth_triangle::*, track::*, triangle::*};
