@@ -1,6 +1,6 @@
 //! Optical attributes.
 
-use crate::{fmt_report, geom::Orient, phys::Material};
+use crate::{fmt_report, geom::Orient, phys::Material, tools::Binner};
 use std::fmt::{Display, Error, Formatter};
 
 /// Surface attributes.
@@ -13,6 +13,8 @@ pub enum Attribute<'a> {
     Spectrometer(usize),
     /// Imager detector id, width, orientation.
     Imager(usize, f64, Orient),
+    /// CCD detector id, width, orientation, binner.
+    Ccd(usize, f64, Orient, Binner),
 }
 
 impl Display for Attribute<'_> {
@@ -35,6 +37,14 @@ impl Display for Attribute<'_> {
                 fmt_report!(fmt, orient, "orientation");
                 Ok(())
             }
+            Self::Ccd(ref id, width, ref orient, ref binner) => {
+                writeln!(fmt, "Ccd: ...")?;
+                fmt_report!(fmt, id, "name");
+                fmt_report!(fmt, width, "width (m)");
+                fmt_report!(fmt, orient, "orientation");
+                fmt_report!(fmt, binner, "binner (m)");
+                Ok(())
+            }
         }
     }
 }
