@@ -4,13 +4,14 @@ pub mod attribute;
 pub mod attribute_linker;
 pub mod attribute_linker_linker;
 pub mod attribute_linker_linker_linker;
+pub mod attribute_linker_linker_linker_linker;
 pub mod engine;
 pub mod engine_builder;
 pub mod engine_builder_loader;
 pub mod engines;
 pub mod event;
+pub mod film_builder;
 pub mod frame;
-pub mod frame_builder;
 pub mod input;
 pub mod output;
 pub mod parameters;
@@ -25,7 +26,8 @@ pub mod travel;
 
 pub use self::{
     attribute::*, attribute_linker::*, attribute_linker_linker::*,
-    attribute_linker_linker_linker::*, engine::*, engine_builder::*, engine_builder_loader::*,
-    event::*, frame::*, frame_builder::*, input::*, output::*, parameters::*,
-    parameters_builder::*, parameters_builder_loader::*, run::*, settings::*,
+    attribute_linker_linker_linker::*, attribute_linker_linker_linker_linker::*, engine::*,
+    engine_builder::*, engine_builder_loader::*, event::*, film_builder::*, frame::*, input::*,
+    output::*, parameters::*, parameters_builder::*, parameters_builder_loader::*, run::*,
+    settings::*,
 };
